{% extends "site_base.html" %}

{% load i18n %}
{% load account_tags %}

{% block head_title %}{% trans "Password reset sent" %}{% endblock %}

{% block body %}
    <h1>{% trans "Password reset sent" %}</h1>
    {% if not resend %}
        <p>{% blocktrans %}We have sent you an email. If you do not receive it within a few minutes, try resending or contact us at <a href="mailto:{{ THEME_CONTACT_EMAIL }}">{{ THEME_CONTACT_EMAIL }}</a>.{% endblocktrans %}</p>
        
        <div class="row">
            <div class="col-md-5">
                <form method="POST" action="{% url "account_password_reset" %}">
                    {% csrf_token %}
                    {% for field in form %}
                        {{ field.as_hidden }}
                    {% endfor %}
                    <button type="submit" name="resend" class="btn btn-primary">{% trans "Resend" %}</button>
                </form>
            </div>
        </div>
    {% else %}
        <p>{% blocktrans %}We have resent the password email. If you do not receive it within a few minutes, contact us at <a href="mailto:{{ THEME_CONTACT_EMAIL }}">{{ THEME_CONTACT_EMAIL }}</a>.{% endblocktrans %}</p>
    {% endif %}
{% endblock %}