body {
  padding-top: 50px;
  position: relative;
}
section {
  padding: 20px 0px;
}
.modal form {
  margin-bottom: 0px;
}
footer {
    padding-bottom: 20px;
}
p.login-signup {
    margin-top: 20px;
}