{% extends "site_base.html" %}

{% load i18n %}

{% block head_title %}{% trans "Confirm your email address" %}{% endblock %}

{% block body %}
    <h2>{% trans "Confirm your email address" %}</h2>
    
    <p>{% blocktrans %}We have sent you an email to <b>{{ email }}</b> for verification. Follow the link provided to finalize the signup process. If you do not receive it within a few minutes, contact us at <a href="mailto:{{ THEME_CONTACT_EMAIL }}">{{ THEME_CONTACT_EMAIL }}</a>.{% endblocktrans %}</p>
    <p><a href="{{ success_url }}">{% trans "Go back" %}</a></p>
{% endblock %}
