{% extends "site_base.html" %}

{% load i18n %}
{% load bootstrap %}

{% block head_title %}{% trans "Set your new password" %}{% endblock %}

{% block body %}
    <div class="row">
        <div class="col-md-5">
            <form method="POST" action="{% url "account_password_reset_token" uidb36=uidb36 token=token %}">
                <legend>{% trans "Set your new password" %}</legend>
                <fieldset>
                    {% csrf_token %}
                    {{ form|bootstrap }}
                    <button type="submit" class="btn btn-primary">{% trans "Save" %}</button>
                </fieldset>
            </form>
        </div>
    </div>
{% endblock %}