{% extends "site_base.html" %}

{% load i18n %}
{% load bootstrap %}

{% block head_title %}{% trans "Log in" %}{% endblock %}

{% block body %}
    <div class="row">
        <div class="col-md-4">
            <form method="POST" action="{% url "account_login" %}" autocapitalize="off" {% if form.is_multipart %} enctype="multipart/form-data"{% endif %}>
                <legend>{% trans "Log in to an existing account" %}</legend>
                {% csrf_token %}
                {{ form|bootstrap }}
                {% if redirect_field_value %}
                    <input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}" />
                {% endif %}
                <button type="submit" class="btn btn-primary">{% trans "Log in" %}</button>
                <a href="{% url "account_password_reset" %}" class="btn btn-link">{% trans "Forgot your password?" %}</a>
            </form>
            {% if ACCOUNT_OPEN_SIGNUP %}
                <p class="login-signup">
                    <small>
                        {% trans "Don't have an account?" %}  <strong><a href="{% url 'account_signup' %}">{% trans "Sign up" %}</a></strong>
                    </small>
                </p>
            {% endif %}
        </div>
        <div class="col-md-4">
            {% include "account/_login_sidebar.html" %}
        </div>
    </div>
{% endblock %}

{% block scripts %}
    {{ block.super }}
    <script type="text/javascript">
        $(document).ready(function() {
            $('#id_username').focus();
        });
    </script>
{% endblock %}
