{% extends "site_base.html" %}

{% load i18n %}

{% block head_title %}{% trans "Bad token" %}{% endblock %}

{% block body %}
    <h1>{% trans "Bad token" %}</h1>
    {% url "account_password_reset" as url %}
    <p>{% blocktrans %}The password reset link was invalid, possibly because it has already been used.  Please request a <a href="{{ url }}">new password reset</a>.{% endblocktrans %}</p>
{% endblock %}