{% extends "account/base.html" %}

{% load i18n %}
{% load bootstrap %}

{% block body_class %}account account-password{% endblock %}

{% block head_title %}{% trans "Change password" %}{% endblock %}

{% block body %}
    <div class="row">
        <div class="col-md-5">
            <form method="POST" action="">
                <legend>{% trans "Change password" %}</legend>
                <fieldset>
                    {% csrf_token %}
                    {{ form|bootstrap }}
                    <button type="submit" class="btn btn-primary">{% trans "Save" %}</button>
                </fieldset>
            </form>
        </div>
    </div>
{% endblock %}