{% load pinax_theme_bootstrap_tags %}
{% for message in messages %}
    <div class="alert fade in {% get_message_tags message %}">
        <button type="button" class="close" data-dismiss="alert">&times;</button>
        {{ message }}
    </div>
{% endfor %}
