{# Includes django-pagination template #}
{# If you want to use django builtin pagination override this template #}
{# and include ``pagination/django_pagination_pagination.html`` instead. #}
{% include "pagination/django_pagination_pagination.html" %}
