{% extends "account/base.html" %}

{% load i18n %}

{% block body_class %}account account-delete{% endblock %}

{% block head_title %}{% trans "Delete Account" %}{% endblock %}

{% block body %}
    <h1>{% trans "Delete Account" %}</h1>
    
    <p>{% blocktrans %}If you go ahead and delete your account, your information will be <b>expunged within {{ ACCOUNT_DELETION_EXPUNGE_HOURS }} hours</b>.{% endblocktrans %}</p>
    
    <form method="post" action="{% url "account_delete" %}" autocapitalize="off">
        {% csrf_token %}
        <button type="submit" class="btn btn-danger">{% trans "Delete My Account" %}</button>
    </form>
    
{% endblock %}
