{% extends "site_base.html" %}

{% load i18n %}
{% load bootstrap %}
{% load account_tags %}

{% block head_title %}{% trans "Password reset" %}{% endblock %}

{% user_display request.user as user_display %}

{% block body %}
    <div class="row">
        <div  class="col-md-8">
            <form method="POST" action="">
                <legend>{% trans "Password reset" %}</legend>
                <p class="lead">{% trans "Forgotten your password? Enter your email address below, and we'll send you an email allowing you to reset it." %}</p>
                <fieldset class="row">
                    <div class="col-md-5">
                        {% csrf_token %}
                        {{ form|bootstrap }}
                        <button type="submit" class="btn btn-primary">
                            {% trans "Reset my password" %}
                        </button>
                    </div>
                </fieldset>
            </form>
        </div>
    </div>
    <p>{% blocktrans %}If you have any trouble resetting your password, contact us at <a href="mailto:{{ THEME_CONTACT_EMAIL }}">{{ THEME_CONTACT_EMAIL }}</a>.{% endblocktrans %}</p>
{% endblock %}

{% block extra_body %}
    <script>
        $("#id_email").focus();
    </script>
{% endblock %}