{% extends "site_base.html" %}

{% load i18n %}

{% block body_base %}
    <section id="content_body">
        <div class="container">
            {% include "_messages.html" %}
            <div class="row">
                <div class="col-md-3 columns">
                    {% block subnav %}
                    {% endblock %}
                </div>
                <div class="col-md-9 columns">
                    {% block body %}
                    {% endblock %}
                </div>
            </div>
        </div>
    </section>
{% endblock %}
